pub struct LumpInfo {
pub pos: i32,
pub size: i32,
pub name: [u8; 8],
pub id: [u8; 12],
pub state: LumpState,
}Expand description
Represents the lump official metadata (16 bytes)
and the WAD operations state (from WadOp)
Fields
pos: i32The lump start position in the file buffer (4 bytes)
size: i32The lump size in bytes (4 bytes)
name: [u8; 8]Lump name, it only contains in theory [A-Z][0-9] (8 bytes)
id: [u8; 12]Lumps name are not unique but we want to extract them into files
The attribute acts like an unique ID
state: LumpStateLump state
Implementations
Sourceimpl LumpInfo
impl LumpInfo
pub fn new(pos: i32, size: i32, name: [u8; 8]) -> Self
Sourcepub fn name_ascii(&self) -> String
pub fn name_ascii(&self) -> String
Get the name filtered by ascii characters only
Sourcepub fn is_overwritable(&self) -> bool
pub fn is_overwritable(&self) -> bool
Returns if the metadata is overwritable
Because specials lumps cannot be overwritten when we build a new WAD file (output) like the separators